@@ -30,7 +30,7 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 
-#include <bonobo/bonobo-dock-layout.h>
+#include "bonobo-dock-layout.h"
 
 /* TODO: handle incorrect BONOBO_DOCK_ITEM_BEH_EXCLUSIVE situations.  */
 
@@ -503,14 +503,14 @@ bonobo_dock_layout_create_string (BonoboDockLayout *layout)
 
       if (i->placement == BONOBO_DOCK_FLOATING)
         tmp[tmp_count] = g_strdup_printf ("%s\\%d,%d,%d,%d",
-                                          i->item->name,
+                                          i->item->name ? i->item->name : "",
                                           (gint) i->placement,
                                           i->position.floating.x,
                                           i->position.floating.y,
                                           i->position.floating.orientation);
       else
         tmp[tmp_count] = g_strdup_printf ("%s\\%d,%d,%d,%d",
-                                          i->item->name,
+                                          i->item->name ? i->item->name : "",
                                           (gint) i->placement,
                                           i->position.docked.band_num,
                                           i->position.docked.band_position,
@@ -519,7 +519,7 @@ bonobo_dock_layout_create_string (BonoboDockLayout *layout)
       tmp_count++;
     }
 
-  tmp[tmp_count] = 0;
+  tmp[tmp_count] = NULL;
 
   retval = g_strjoinv ("\\", tmp);
   g_strfreev (tmp);
